@@ -13,7 +13,6 @@ from amuse.units.si import none
 from amuse.units.core import zero_unit
 
 
-
 """
 """
 class Quantity(object):
@@ -278,7 +277,14 @@ class ScalarQuantity(Quantity):
         # Quantity.__init__(self, unit)
         # commented out super call, this speeds thing up
         self.unit = unit
-        self.number = number
+        if unit.dtype is None:
+            self.number = number
+        else:
+            if isinstance(unit.dtype, numpy.dtype):
+                self.number = unit.dtype.type(number)
+            else:
+                self.number = unit.dtype(number)
+
 
     def is_scalar(self):
         return True
@@ -318,9 +324,9 @@ class ScalarQuantity(Quantity):
         array = numpy.zeros(length, dtype=self.unit.dtype)
         return new_quantity(array, self.unit)
 
-    def __setstate__(self, tuple):
-        self.unit = tuple[0]
-        self.number = tuple[1]
+    def __setstate__(self, x):
+        self.unit = x[0]
+        self.number = x[1]
 
     def sum(self, axis=None, dtype=None, out=None):
         return self
@@ -511,7 +517,7 @@ class VectorQuantity(Quantity):
         >>> v1.prod(2)
         quantity<[[6.0, 8.0], [10.0, 12.0]] m**2>
         """
-        if axis == None:
+        if axis is None:
             return new_quantity_nonone(self.number.prod(axis, dtype), self.unit ** numpy.prod(self.number.shape))
         else:
             return new_quantity_nonone(self.number.prod(axis, dtype), self.unit ** self.number.shape[axis])
@@ -600,8 +606,7 @@ class VectorQuantity(Quantity):
         except AttributeError:
             if not is_quantity(vector):
                 raise ValueError("Tried to put a non quantity value in a quantity")
-            else:
-                raise
+            raise
 
     def __setitem__(self, index, quantity):
         """Update the "index" component to the specified quantity.
@@ -920,9 +925,9 @@ class VectorQuantity(Quantity):
     def __getstate__(self):
         return (self.unit, self.number)
 
-    def __setstate__(self, tuple):
-        self.unit = tuple[0]
-        self._number = tuple[1]
+    def __setstate__(self, x):
+        self.unit = x[0]
+        self._number = x[1]
 
 
 class ZeroQuantity(Quantity):
@@ -1118,9 +1123,9 @@ class NonNumericQuantity(Quantity):
     def __getstate__(self):
         return (self.unit, self.value)
 
-    def __setstate__(self, tuple):
-        self.unit = tuple[0]
-        self.value = tuple[1]
+    def __setstate__(self, x):
+        self.unit = x[0]
+        self.value = x[1]
 
 class AdaptingVectorQuantity(VectorQuantity):
     """
@@ -1223,14 +1228,11 @@ def new_quantity_nonone(value, unit):
         return NonNumericQuantity(value, unit)
     return ScalarQuantity(value, unit)
 
-def is_quantity(input):
-    return hasattr(input, "is_quantity") and input.is_quantity()
+def is_quantity(x):
+    return hasattr(x, "is_quantity") and x.is_quantity()
 
-def is_unit(input):
-    if hasattr(input, "base"):
-        return True
-    else:
-        return False
+def is_unit(x):
+    return hasattr(x, "base")
 
 def isNumber(x):
     try:
@@ -1255,16 +1257,17 @@ def as_vector_quantity(value):
             else:
                 raise Exception("Cannot convert '{0!r}' to a vector quantity".format(value))
 
-def to_quantity(input):
-    if is_quantity(input):
-        return input
+def to_quantity(x):
+    if is_quantity(x):
+        return x
     else:
-        return new_quantity(input, none)
+        return new_quantity(x, none)
 
-def as_quantity_in(input,unit):
-    return to_quantity(input).as_quantity_in(unit)
-def value_in(input,unit):
-    return to_quantity(input).value_in(unit)
+def as_quantity_in(x,unit):
+    return to_quantity(x).as_quantity_in(unit)
+
+def value_in(x,unit):
+    return to_quantity(x).value_in(unit)
 
 def concatenate(quantities):
     first = quantities[0]
@@ -1310,7 +1313,6 @@ def linspace(start, stop, num = 50,  endpoint=True, retstep=False):
         return new_quantity(array, unit)
 
 def separate_numbers_and_units(values):
-    from amuse.units.si import none
     number = []
     unit = []
     for value in values:
@@ -1346,7 +1348,6 @@ def polyval(p, x):
     y_unit = p_unit[-1].to_reduced_form()
     x_unit = (y_unit/p_unit[-2]).to_reduced_form()
 
-    from amuse.units.si import none
     if x_unit != none:
         x = x.value_in(x_unit)
 
@@ -1359,58 +1360,3 @@ def searchsorted(a, v, **kwargs):
         return numpy.searchsorted(a.value_in(a.unit), v.value_in(a.unit), **kwargs)
     else:
         return numpy.searchsorted(a, v, **kwargs)
-
-def numpy_or_operator(array, other, out = None):
-    if isinstance(other, unit):
-        return other.new_quantity(array)
-    else:
-        return numpy.bitwise_or(array, other, out)
-
-def numpy_div_operator(array, other, out = None):
-    if is_quantity(other):
-        return other.__rdiv__(array)
-    else:
-        return numpy.divide(array, other, out)
-
-def numpy_true_div_operator(array, other, out = None):
-    if is_quantity(other):
-        return other.__rtruediv__(array)
-    else:
-        return numpy.true_divide(array, other, out)
-
-def numpy_multiply_operator(array, other, out = None):
-    if is_quantity(other):
-        return other.__rmul__(array)
-    else:
-        return numpy.multiply(array, other, out)
-
-numpy_multiply_operator.reduce = numpy.multiply.reduce
-numpy_true_div_operator.reduce = numpy.true_divide.reduce
-numpy_div_operator.reduce = numpy.divide.reduce
-numpy_multiply_operator.accumulate = numpy.multiply.accumulate
-numpy_true_div_operator.accumulate = numpy.true_divide.accumulate
-numpy_div_operator.accumulate = numpy.divide.accumulate
-numpy_multiply_operator.reduceat = numpy.multiply.reduceat
-numpy_true_div_operator.reduceat = numpy.true_divide.reduceat
-numpy_div_operator.reduceat = numpy.divide.reduceat
-
-_previous_operators = None
-
-def set_numpy_operators():
-    import atexit
-
-    global _previous_operators
-
-    _previous_operators = numpy.set_numeric_ops(
-        multiply = numpy_multiply_operator,
-        divide = numpy_div_operator,
-        true_divide = numpy_true_div_operator
-    )
-    atexit.register(unset_numpy_operators)
-
-def unset_numpy_operators():
-    global _previous_operators
-    numpy.set_numeric_ops(**_previous_operators)
-
-if compare_version_strings(numpy.__version__, '1.5.0') >= 0:
-    set_numpy_operators()
